@@ -11,7 +11,7 @@ import dlapp
 import textfsm
 import yaml
 
-__version__ = '0.1.5'
+__version__ = '0.1.7'
 version = __version__
 __edition__ = 'Community'
 edition = __edition__
@@ -96,3 +96,25 @@ class Data:
         OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
         """.format(years, company)
     ).strip()
+
+    @classmethod
+    def get_dependency(cls):
+        dependencies = dict(
+            regexapp=dict(
+                package=cls.regexapp_text,
+                url=cls.regexapp_link
+            ),
+            dlapp=dict(
+                package=cls.dlapp_text,
+                url=cls.dlapp_link
+            ),
+            textfsm=dict(
+                package=cls.textfsm_text,
+                url=cls.textfsm_link
+            ),
+            pyyaml=dict(
+                package=cls.pyyaml_text,
+                url=cls.pyyaml_link
+            )
+        )
+        return dependencies
