@@ -11,6 +11,8 @@ from textwrap import dedent
 from regexapp import LinePattern
 from regexapp.core import enclose_string
 
+from dlapp.collection import Tabular
+
 from templateapp.exceptions import TemplateParsedLineError
 from templateapp.exceptions import TemplateBuilderError
 from templateapp.exceptions import TemplateBuilderInvalidFormat
@@ -49,7 +51,7 @@ class ParsedLine:
     kept_str (str): a kept text.
     variables (list): a list of variables.
 
-    Properties  # noqa
+    Properties
     ----------
     is_empty (bool): True if a line does not have data, otherwise False.
     is_a_word (bool): True if text is a single word, otherwise False.
@@ -116,17 +118,6 @@ class ParsedLine:
 
         pat_obj = LinePattern(self.line, ignore_case=self.ignore_case)
 
-        if self.is_comment:
-            text = self.text[8:].strip()
-            return '  # {}'.format(text)
-
-        if self.is_kept:
-            text = self.text
-            if re.match(r' *\^', text):
-                return '  {}'.format(text.lstrip())
-            else:
-                return '  ^{}'.format(text)
-
         if pat_obj.variables:
             self.variables = pat_obj.variables[:]
             statement = pat_obj.statement
@@ -186,26 +177,23 @@ class ParsedLine:
         else:
             text = self.text
 
-        pat = r'(?P<flag>(ignore_case|comment|keep) )?(?P<line>.*)'
+        pat = r'^(?P<flag>(ignore_case|comment|keep)__+ )?(?P<line>.*)'
         match = re.match(pat, text, re.I)
         if match:
-            flag = match.group('flag') or ''
-            flag = flag.strip()
+            value = match.group('flag') or ''
+            flag = value.lower().strip().rstrip('_')
             self.ignore_case = flag == 'ignore_case'
             self.is_comment = flag == 'comment'
             self.is_kept = flag == 'keep'
             self.line = match.group('line') or ''
 
             if self.is_comment:
-                txt = self.text[8:].strip().lstrip('#')
-                self.comment_text = '  # {}'.format(txt)
+                prefix = '  ' if value.count('_') == 2 else ''
+                self.comment_text = '{}# {}'.format(prefix, self.line)
 
             if self.is_kept:
-                txt = self.text[5:]
-                if txt.lstrip().startswith('^'):
-                    self.kept_text = '  {}'.format(txt.lstrip())
-                else:
-                    self.kept_text = '  ^{}'.format(txt)
+                self.kept_text = '  ^{}'.format(self.line.strip().lstrip('^'))
+
         else:
             error = 'Invalid format - {!r}'.format(self.text)
             raise TemplateParsedLineError(error)
@@ -351,6 +339,7 @@ class TemplateBuilder:
         lst = []
         pat = r'[\r\n]+[a-zA-Z]\w*([\r\n]+|$)'
         start = 0
+        m = None
         for m in re.finditer(pat, self.template):
             before_match = m.string[start:m.start()]
             state = m.group().strip()
@@ -362,8 +351,8 @@ class TemplateBuilder:
             lst.append(state)
             start = m.end()
         else:
-            if lst:
-                after_match = m.string[m.end():]    # noqa
+            if m and lst:
+                after_match = m.string[m.end():]
                 if after_match.strip():
                     for line in after_match.splitlines():
                         if line.strip():
@@ -407,13 +396,15 @@ class TemplateBuilder:
             msg = 'user_data does not have any assigned variable for template.'
             raise TemplateBuilderInvalidFormat(msg)
 
-    def show_debug_info(self, test_result=None, expected_result=None):
+    def show_debug_info(self, test_result=None, expected_result=None,
+                        tabular=False):
         """show debug information
         
         Parameters
         ----------
         test_result (list): a list of dictionary.
         expected_result (list): a list of dictionary.
+        tabular (bool): show result in tabular format.  Default is False.
         """
         if self.verified_message:
             lst = [
@@ -435,16 +426,30 @@ class TemplateBuilder:
                     '------------',
                     pformat(test_result)
                 ]
-            msg = '\n'.join(lst) + '\n'
-            self.logger.debug(msg)
 
-    def verify(self, expected_rows_count=None, expected_result=None, debug=False):
+            if test_result:
+                lst += [
+                    'Test result:',
+                    '------------',
+                    Tabular(test_result).get() if tabular else pformat(test_result)
+                ]
+
+            lst += ['Verified message:',
+                    '-----------------',
+                    self.verified_message]
+
+            msg = '\n'.join(lst) + '\n'
+            print(msg)
+
+    def verify(self, expected_rows_count=None, expected_result=None,
+               tabular=False, debug=False):
         """verify test_data via template
         
         Parameters
         ----------
         expected_rows_count (int): total number of rows.
         expected_result (list): a list of dictionary.
+        tabular (bool): show result in tabular format.  Default is False.
         debug (bool): True will show debug info.  Default is False.
 
         Returns
@@ -479,15 +484,18 @@ class TemplateBuilder:
             if expected_result is not None:
                 chk = rows == expected_result
                 is_verified &= chk
-                if not chk:
-                    msg = 'Parsed result is as same as expected result.'
-                    if self.verified_message:
-                        self.verified_message += '\n{}'.format(msg)
-                    else:
-                        self.verified_message = msg
 
-            if not is_verified and debug:
-                self.show_debug_info(test_result=rows, expected_result=expected_result)
+                fmt = 'Parsed result is {} expected result.'
+                msg = fmt.format('AS SAME AS' if chk else 'NOT the same with')
+                self.verified_message += '\n{}'.format(msg).strip()
+
+            if is_verified and not self.verified_message:
+                self.verified_message = 'Parsed result has some data.'
+
+            if debug:
+                self.show_debug_info(test_result=rows,
+                                     expected_result=expected_result,
+                                     tabular=tabular)
 
             return is_verified
 
@@ -622,7 +630,7 @@ class TemplateBuilder:
                 print("Test data:\n----------\n%s" % test_data_)
                 print("\n%s\n" % ("+" * 40))
                 
-                # show textfms template
+                # show textfsm template
                 print("Template:\n---------\n%s" % template_)
                 
                 stream = StringIO(template_)
